@@ -1,12 +1,13 @@
 from __future__ import annotations
 
+import platform
 from dataclasses import dataclass
 from pathlib import Path
 
 from .types import LightDark
 
 CONFIG_PATH = Path.home() / '.config/hyfetch.json'
-VERSION = '1.4.6'
+VERSION = '1.4.7'
 
 
 TEST_ASCII = r"""
@@ -25,7 +26,7 @@ _/\_\_   _/_/\_
 
 TEST_ASCII_WIDTH = max(len(line) for line in TEST_ASCII.split('\n'))
 DEFAULT_DARK_L = 0.
-
+IS_WINDOWS = platform.system() == 'Windows'
 
 @dataclass
 class GlobalConfig:
