@@ -4,6 +4,7 @@ import os
 import platform
 import re
 import shlex
+import shutil
 import subprocess
 import sys
 import zipfile
@@ -15,13 +16,12 @@ from tempfile import TemporaryDirectory
 import pkg_resources
 
 from .color_util import color, printc
-from .constants import GLOBAL_CFG, MINGIT_URL
+from .constants import GLOBAL_CFG, MINGIT_URL, IS_WINDOWS
 from .distros import distro_detector
 from .presets import ColorProfile
 from .serializer import from_dict
 from .types import BackendLiteral, ColorAlignMode
 
-
 RE_NEOFETCH_COLOR = re.compile('\\${c[0-9]}')
 
 
@@ -136,6 +136,16 @@ class ColorAlignment:
         return asc
 
 
+def if_file(f: str | Path) -> Path | None:
+    """
+    Return the file if the file exists, or return none. Useful for chaining 'or's
+    """
+    f = Path(f)
+    if f.is_file():
+        return f
+    return None
+
+
 def get_command_path() -> str:
     """
     Get the absolute path of the neofetch command
@@ -145,8 +155,19 @@ def get_command_path() -> str:
     cmd_path = pkg_resources.resource_filename(__name__, 'scripts/neowofetch')
 
     # Windows doesn't support symbolic links, but also I can't detect symbolic links... hard-code it here for now.
-    if platform.system() == 'Windows':
-        return str(Path(cmd_path).parent.parent.parent / 'neofetch')
+    if IS_WINDOWS:
+        pkg = Path(__file__).parent
+        pth = (shutil.which("neowofetch") or
+               if_file(cmd_path) or
+               if_file(pkg / 'scripts/neowofetch') or
+               if_file(pkg.parent / 'neofetch') or
+               if_file(Path(cmd_path).parent.parent.parent / 'neofetch'))
+
+        if not pth:
+            printc("&cError: Neofetch script cannot be found")
+            exit(127)
+
+        return str(pth)
 
     return cmd_path
 
@@ -157,12 +178,21 @@ def ensure_git_bash() -> Path:
 
     :returns git bash path
     """
-    if platform.system() == 'Windows':
+    if IS_WINDOWS:
         # Find installation in default path
         def_path = Path(r'C:\Program Files\Git\bin\bash.exe')
         if def_path.is_file():
             return def_path
 
+        # Detect third-party git.exe in path
+        git_exe = shutil.which("git.exe") or shutil.which("git")
+        if git_exe is not None:
+            pth = Path(git_exe).parent
+            if (pth / r'bash.exe').is_file():
+                return pth / r'bash.exe'
+            elif (pth / r'bin\bash.exe').is_file():
+                return pth / r'bin\bash.exe'
+
         # Find installation in PATH (C:\Program Files\Git\cmd should be in path)
         pth = (os.environ.get('PATH') or '').lower().split(';')
         pth = [p for p in pth if p.endswith(r'\git\cmd')]
@@ -192,7 +222,7 @@ def check_windows_cmd():
     Check if this script is running under cmd.exe. If so, launch an external window with git bash
     since cmd doesn't support RGB colors.
     """
-    if platform.system() == 'Windows':
+    if IS_WINDOWS:
         import psutil
         # TODO: This line does not correctly identify cmd prompts...
         if psutil.Process(os.getppid()).name().lower().strip() == 'cmd.exe':
@@ -207,13 +237,13 @@ def run_neofetch_cmd(args: str, pipe: bool = False) -> str | None:
     Run neofetch command
     """
     if platform.system() != 'Windows':
-        full_cmd = shlex.split(f'/usr/bin/env bash {get_command_path()} {args}')
+        full_cmd = ['/usr/bin/env', 'bash', get_command_path(), *shlex.split(args)]
 
     else:
         cmd = get_command_path().replace("\\", "/").replace("C:/", "/c/")
         args = args.replace('\\', '/').replace('C:/', '/c/')
 
-        full_cmd = [ensure_git_bash(), '-c', f'{cmd} {args}']
+        full_cmd = [ensure_git_bash(), '-c', f"'{cmd}' {args}"]
     # print(full_cmd)
 
     if pipe:
